global MyPath = "/Users/matthieugomez/Dropbox/Projects/qtheory/final files/Replication"


using Pkg
Pkg.add(["Plots", "LaTeXStrings"])
using Plots, LaTeXStrings
blue = colorant"rgb(68, 118, 170)"
red = colorant"rgb(204, 102, 119)"

#===========================================================================================
Define Model
===========================================================================================#

Base.@kwdef mutable struct StylizedModel
	g::Float64 = 0.5
	i::Float64 = 0.4
	τ::Float64 = 0.5
	η::Float64 = 0.05
	ρ::Float64 = 0.04
end

function solve(m::StylizedModel, r)
	(; g, i, τ, η, ρ) = m
	if r - (g - τ ) > 0
		q = (- i + τ) / (r - (g - τ))
	else
		q = Inf
	end
	θR = (r - ρ) / η
	converged = (q > 0) & (- i + τ > 0)
	if !converged
		q = 100.0
	end
	θE = (- i / q + g - ρ) / (η + τ) 
	θ = max(θR, θE)
	return (q = q, θR = θR, θE = θE, θ = θ)
end

function compute_rstar(m)
	(; g, i, τ, η, ρ) = m
	(- i + τ) / (- i + τ + η) * (ρ + η) + η / (- i + τ + η) * (g - τ)
end

#===========================================================================================
Wealth Path
===========================================================================================#
m = StylizedModel()

# Realized wealth
N = 50
T = 15
iend = T * div(1000, N)
ts = range(0, N, length = 1000)

r_high = 0.05
q_high = solve(m, r_high).q
Ws1_high = q_high .* exp.((- m.i / q_high + m.g - m.ρ) .* ts[1:iend])
Ws2_high = Ws1_high[end] ./ q_high .* exp.((r_high - m.ρ) .* (ts[(iend+1):(end)] .- ts[iend]))
Ws2_high[1] = NaN
Ws_high = vcat(Ws1_high, Ws2_high)

r_low = 0.03
q_low = solve(m, r_low).q
Ws1_low = q_low .* exp.((- m.i / q_low + m.g - m.ρ) .* ts[1:iend])
Ws2_low = Ws1_low[end] ./ q_low .* exp.((r_low - m.ρ) .* (ts[(iend+1):(end)] .- ts[iend]))
Ws2_low[1] = NaN
Ws_low = vcat(Ws1_low, Ws2_low)

p = plot(ts, [Ws_high Ws_low], xlabel = "Age", ylabel = "Wealth",  label = [L"r = 5\%" L"r = 3\%"], color = [blue red], linestyle = [:solid :dash], legend = :none, linewidth = [2 2], xtickfontsize = 14, ytickfontsize = 14, guidefontsize = 14, legendfontsize = 14)
plot!([ts[iend+1]], seriestype="vline", color = :black, linestyle = :dot, label = "")
annotate!([(25, 30, (L"r = 5\%", 14, blue, :center)), (25, 180, (L"r = 3\%", 14, red, :center))])
savefig(p, "$(MyPath)/Output/Figures/Figure1.pdf") 

#===========================================================================================
U-Shape
===========================================================================================#

m = StylizedModel()
r_star = compute_rstar(m)
rs = range(m.g .- m.τ, m.ρ + m.η, length = 100)
sols = [solve(m, r) for r in rs]
qs = [sol.q for sol in sols]
θRs = [sol.θR for sol in sols]
θEs = [sol.θE for sol in sols]

θs = max.(θEs, θRs)
@assert all(max.(θRs, θEs) .>= 0)
@assert θEs[1] > θRs[1]
@assert θEs[end] < θRs[end]


p = plot(rs, [replace(x -> x > 0.0 ? x : NaN, θEs) replace(x -> x > 0.0 ? x : NaN, θRs)  θs], color = [blue red :black], linestyle = [:solid :dash  :solid], linewidth = [2 2 10], linealpha = [1 1 0.08], xlabel = L"\textrm{Interest Rate } r ", ylabel = L"\textrm{Pareto Inequality } \theta", xticks=([0, 0.03, 0.06, 0.09 ], [L"0\%", L"3\%", L"6\%", L"9\%"]), legend=:none, xtickfontsize = 14, ytickfontsize = 14, guidefontsize = 14, legendfontsize = 40)
annotate!([(0.03, 0.75, (L"\frac{g -i/q - \rho}{\eta + \tau}", 20, blue, :center)), (0.07, 0.75, (L"\frac{r-\rho}{\eta}", 20, red, :center))])
savefig(p, "$(MyPath)/Output/Figures/Figure2.pdf") 


