
/***************************************************************************************************
Merge with other datasets
***************************************************************************************************/
* CPI price level
import delimited using "$MyPath/Data/FRED/CPIAUCSL.csv", clear case(preserve)
gen year = year(date(date, "YMD"))
collapse (mean) cpiaucsl = CPIAUCSL, by(year)
tempfile temp_cpi
save `temp_cpi'

* Population growth
import delimited using "$MyPath/Data/FRED/SPPOPGROWUSA.csv", clear case(preserve)
gen year = year(date(date, "YMD"))
gen g_pop = SPPOPGROWUSA / 100
keep year g_pop
tempfile temp_pop
save `temp_pop'

* TFP
import delimited using "$MyPath/Data/FRED/RTFPNAUSA632NRUG.csv", clear case(preserve)
gen year = year(date(date, "YMD"))
rename RTFPNAUSA632NRUG tfp
tsset year
gen g_tfp = tfp / L.tfp - 1
tempfile temp_tfp
save `temp_tfp'

* Integrated Macroeconomic Accounts
import delimited using "$MyPath/Data/IMA.csv", clear  case(preserve)
merge 1:1 year using `temp_cpi', keep(master matched) nogen
ds year cpiaucsl, not
foreach v in `=r(varlist)'{
	replace `v'=`v' / cpiaucsl
}
merge 1:1 year using `temp_pop', keep(master matched) nogen
merge 1:1 year using `temp_tfp', keep(master matched) nogen

rename W326RC NOS
rename LA000134 NI
rename LM102010005 K
rename FL104194005 L
rename FL104122005 DebtSecurities
rename FL104135005 Loans
rename FL103192105 FDI

* Return on Capital
tsset year
gen g_K = NI / L.K
gen rok = NOS / L.K

* Tobin's Q
gen FinancialAssets = FL104000005 + LM104022005 + FL103034000 + LM103064103 + LM103064203
gen Q = (L - FDI - FinancialAssets) / K

* Return on wealth
gen Er = (rok - g_K) / L.Q + g_K
gen Er_gK = Er - (g_K - g_pop)
gen Er_gtfp = Er - g_tfp

save "$MyPath/save/Er", replace

/***************************************************************************************************

***************************************************************************************************/
use "$MyPath/save/Er", clear

/* FIGURE 3.—Returns and valuation for the U.S. nonfinancial corporate sector a) Returns  */
twoway (line Er year if year >= 1970, lwidth(thick) color("$blue")) ///
(line rok year if year >= 1970, lwidth(thick) lpattern(shortdash) color("$red")), ///
xlabel(, labsize(large) grid glcolor(gs14) glwidth(vthin)) graphregion(color(white)) ///
ylabel(0.025[0.025]0.1, labsize(large)  grid angle(0)) ///
yscale(range(0.025 0.108)) ///
xtitle("", size(large)) ytitle("", size(large))  ///
legend(off) /// 
text(0.037 2020 "Required return on wealth", color("$blue") size(large) placement(west)) ///
text(0.102 2020 "Return on capital", color("$red") size(large) placement(west))
graph export "$MyPath/Output/Figures/Figure3a.pdf", replace

/* FIGURE 3.—Returns and valuation for the U.S. nonfinancial corporate sector a) Tobin's q */
twoway (line Q year if year >= 1970, lwidth(thick)  color("$blue")), ysize(4) xsize(6) ///
xlabel(, labsize(large) grid glcolor(gs14) glwidth(vthin)) graphregion(color(white)) ///
ylabel(0[1]3, labsize(large)  grid angle(0)) ///
xtitle("", size(large))  ytitle("", size(large)) ///
legend(off) /// 
text(2.5 2018 "Tobin's Q", color("$blue") size(large) placement(west))
graph export "$MyPath/Output/Figures/Figure3b.pdf", replace

/* Figure C1: FIGURE C.1.—Required returns net of aggregate growth */
twoway (line Er year if year >= 1970, lwidth(thick) color("$blue")) ///
(line Er_gK year if year >= 1970, lwidth(thick) lpattern(shortdash) color("$red")) ///
(line Er_gtfp year if year >= 1970, lwidth(thick) lpattern(dash) color("$yellow")), ///
xlabel(, labsize(medlarge) grid glcolor(gs14) glwidth(vthin)) graphregion(color(white)) ///
ylabel(0.025[0.025]0.1, labsize(medlarge)  grid angle(0)) ///
ytitle("", size(large))  xtitle("", size(large)) ///
legend(order(1 "Gross required return on wealth" 2 "Deflated by capital formation per capita" 3 "Deflated by TFP growth") size(medium) rows(4) symysize(6) symxsize(6) region(lwidth(vvthin)))
graph export "$MyPath/Output/Figures/FigureC2.pdf", replace

/* Output statistics */
tempname handle
file open `handle' using "$MyPath/Output/Numbers/stat_Er_pre.tex", write replace
sum Er if inrange(year, 1980, 1985)
local m1 = r(mean)
file write `handle' "`:di %2.1fc `= 100 * `m1'''"
file close `handle'

tempname handle
file open `handle' using "$MyPath/Output/Numbers/stat_Er_post.tex", write replace
sum Er if inrange(year, 2015, 2020)
local m2 = r(mean)
file write `handle' "`:di %2.1fc `= 100 * `m2'''"
file close `handle'

tempname handle
file open `handle' using "$MyPath/Output/Numbers/stat_Er_diff.tex", write replace
file write `handle' "`:di %2.1fc `= 100 * (`m2' - `m1')''"
file close `handle'

tempname handle
file open `handle' using "$MyPath/Output/Numbers/stat_Er_gK_diff.tex", write replace
sum Er_gK if inrange(year, 1980, 1985)
local v1 = r(mean)
sum Er_gK if inrange(year, 2015, 2020)
local v2 = r(mean)
file write `handle' "`:di %2.1fc `= 100 * (`v2' - `v1')''"
file close `handle'

tempname handle
file open `handle' using "$MyPath/Output/Numbers/stat_Er_gtfp_diff.tex", write replace
sum Er_gtfp if inrange(year, 1980, 1985)
local v1 = r(mean)
sum Er_gtfp if inrange(year, 2015, 2020)
local v2 = r(mean)
file write `handle' "`:di %2.1fc `= 100 * (`v2' - `v1')''"
file close `handle'

/* TABLE C.VI  RETURNS AND VALUATIONS OF THE U.S. CORPORATE SECTOR */
tempfile postfile
tempname postname
postfile `postname' str80 varname pre mean post using `postfile'
label var rok "Return on capital (\%)"
label var Er "Required return on wealth (\%)"
label var Er_gK "Required return on wealth net of capital growth p.c. (\%)"
label var Er_gtfp "Required return on wealth net of TFP growth (\%)"
label var Q "Tobin's q"
foreach v of varlist rok Er Er_gK Er_gtfp Q {
	if "`v'" != "q"{
		replace `v' = `v' * 100
	}
	sum `v' if inrange(year, 1980, 1985)
	local m_pre = r(mean)
	sum `v' if inrange(year, 1980, 2020)
	local m = r(mean)
	sum `v' if inrange(year, 2015, 2020)
	local m_post = r(mean)
	post `postname' (`"`:var label `v''"') (`m_pre') (`m') (`m_post')
}
postclose `postname'
use `postfile', clear
format pre mean post %4.1fc
listtab varname pre mean post using  "$MyPath/Output/Tables/TableCIII.tex", rstyle(tabular) replace 

/***************************************************************************************************
Return on Debt
***************************************************************************************************/

import delimited using "$MyPath/Data/FRED/DPRIME.csv", clear case(preserve)
gen year = year(date(date, "YMD"))
collapse  (mean) dprime = DPRIME, by(year)
replace dprime = dprime / 100
drop if missing(year)
tempfile temp_prime
save `temp_prime'

import delimited using "$MyPath/Data/FRED/AAA.csv", clear case(preserve)
gen year = year(date(date, "YMD"))
collapse  (mean) aaa = AAA, by(year)
replace aaa = aaa / 100
tempfile temp_aaa
save `temp_aaa'

import delimited using "$MyPath/Data/FRED/BAA.csv", clear case(preserve)
gen year = year(date(date, "YMD"))
collapse  (mean) baa = BAA, by(year)
replace baa = baa / 100
tempfile temp_baa
save `temp_baa'

import delimited using "$MyPath/Data/FRED/CPIAUCSL.csv", clear case(preserve)
gen year = year(date(date, "YMD"))
gen month = month(date(date, "YMD"))
keep if month == 12
tsset year
gen infl = CPIAUCSL / L.CPIAUCSL - 1
keep year infl
tempfile temp_infl
save `temp_infl'

use `temp_prime'
merge 1:1 year using `temp_aaa', nogen
merge 1:1 year using `temp_baa', nogen
merge 1:1 year using `temp_infl', nogen
gen dprime_real = dprime - (L.infl + L2.infl + L3.infl) / 3
gen aaa_real = aaa - (L.infl + L2.infl + L3.infl) / 3
gen baa_real = baa - (L.infl + L2.infl + L3.infl) / 3
merge 1:1 year using "$MyPath/save/Er", keepusing(DebtSecurities Loans g_K g_pop g_tfp) keep(master matched) nogen
gen Er_debt = (DebtSecurities * baa_real + Loans * dprime_real) / (DebtSecurities + Loans)
gen Er_debt_gK = Er_debt - (g_K - g_pop)
gen Er_debt_gtfp = Er_debt - g_tfp

/* FIGURE C.2.—Required return on corporate debt a) */
twoway  (line aaa_real year if inrange(year, 1980, 2020), lwidth(thick) lpattern(solid) color("$blue")) ///
(line baa_real year if inrange(year, 1980, 2020), lwidth(thick) lpattern(dash) color("$red")), ///
xlabel(, labsize(large) grid glcolor(gs14) glwidth(vthin)) graphregion(color(white)) ///
ylabel(0.0[0.025]0.1, labsize(large)  grid angle(0)) ///
ytitle("", size(large))  xtitle("", size(large)) ///
legend(off) ///
text(0.015 2007 "AAA", color("$blue") size(large) placement(east)) ///
text(0.057 2007 "BAA", color("$red") size(large) placement(east))
graph export "$MyPath/Output/Figures/FigureC3a.pdf", replace

/* FIGURE C.2.—Required return on corporate debt b) */
twoway  (line dprime_real year if inrange(year, 1980, 2020), lwidth(thick) lpattern(solid) color("$blue")), ///
xlabel(, labsize(large) grid glcolor(gs14) glwidth(vthin)) graphregion(color(white)) ///
ylabel(0.0[0.025]0.1, labsize(large)  grid angle(0)) ///
ytitle("", size(large))  xtitle("", size(large)) ///
text(0.04 2010 "Prime loan rate", color("$blue") size(large) placement(centered)) ///
legend(off)
graph export "$MyPath/Output/Figures/FigureC3b.pdf", replace

/* FIGURE C.3.—Deflated required return on corporate debt  */
twoway (line Er_debt year if inrange(year, 1980, 2020), lwidth(thick) color("$blue")) ///
(line Er_debt_gK year if inrange(year, 1980, 2020), lwidth(thick) lpattern(shortdash) color("$red")) ///
(line Er_debt_gtfp year if inrange(year, 1980, 2020), lwidth(thick) lpattern(dash) color("$yellow")), ///
xlabel(, labsize(medlarge) grid glcolor(gs14) glwidth(vthin)) graphregion(color(white)) ///
ylabel(0.0[0.025]0.1, labsize(medlarge)  grid angle(0)) ///
ytitle("", size(large))  xtitle("", size(large)) ///
legend(order(1 "Gross required return on corporate debt" 2 "Deflated by capital formation per capita" 3 "Deflated by TFP growth") size(medium) rows(4) symysize(6) symxsize(6) region(lwidth(vvthin)))
graph export "$MyPath/Output/Figures/FigureC4.pdf", replace

/* Output statistics */
tempname handle
file open `handle' using "$MyPath/Output/Numbers/stat_Er_debt_diff.tex", write replace
sum Er_debt if inrange(year, 1980, 1985)
local v1 = r(mean)
sum Er_debt if inrange(year, 2015, 2020)
local v2 = r(mean)
file write `handle' "`:di %2.1fc `= 100 * (`v2' - `v1')''"
file close `handle'

file open `handle' using "$MyPath/Output/Numbers/stat_Er_debt_gK_diff.tex", write replace
sum Er_debt_gK if inrange(year, 1980, 1985)
local v1 = r(mean)
sum Er_debt_gK if inrange(year, 2015, 2020)
local v2 = r(mean)
file write `handle' "`:di %2.1fc `= 100 * (`v2' - `v1')''"
file close `handle'

file open `handle' using "$MyPath/Output/Numbers/stat_Er_debt_gtfp_diff.tex", write replace
sum Er_debt_gtfp if inrange(year, 1980, 1985)
local v1 = r(mean)
sum Er_debt_gtfp if inrange(year, 2015, 2020)
local v2 = r(mean)
file write `handle' "`:di %2.1fc `= 100 * (`v2' - `v1')''"
file close `handle'

/* TABLE C.VII REQUIRED RETURN ON CORPORATE DEBT */
tempfile postfile
tempname postname
postfile `postname' str80 varname pre mean post using `postfile'
label var Er_debt "Interest on corporate debt (\%)"
label var Er_debt_gK "Interest on corporate debt net of capital growth p.c. (\%)"
label var Er_debt_gtfp "Interest on corporate debt net of TFP growth (\%)"
foreach v of varlist Er_debt Er_debt_gK Er_debt_gtfp {
	replace `v' = `v' * 100
	sum `v' if inrange(year, 1980, 1985)
	local m_pre = r(mean)
	sum `v' if inrange(year, 1980, 2020)
	local m = r(mean)
	sum `v' if inrange(year, 2015, 2020)
	local m_post = r(mean)
	post `postname' (`"`:var label `v''"') (`m_pre') (`m') (`m_post')
}
postclose `postname'
use `postfile', clear
format pre mean post %4.1fc
listtab varname pre mean post using  "$MyPath/Output/Tables/TableCIV.tex", rstyle(tabular) replace 
